package com.huijy.management.service;

import java.util.List;

import com.huijy.management.domain.ShopRoomOrder;

/**
 * 酒店房间预订Service接口
 *
 * @author lishuwen
 * @date 2021-11-10
 */
public interface IShopRoomOrderService {
    /**
     * 查询酒店房间预订
     *
     * @param id 酒店房间预订主键
     * @return 酒店房间预订
     */
    public ShopRoomOrder selectShopRoomOrderById(Long id);

    /**
     * 查询酒店房间预订列表
     *
     * @param shopRoomOrder 酒店房间预订
     * @return 酒店房间预订集合
     */
    public List<ShopRoomOrder> selectShopRoomOrderList(ShopRoomOrder shopRoomOrder);

    /**
     * 新增酒店房间预订
     *
     * @param shopRoomOrder 酒店房间预订
     * @return 结果
     */
    public int insertShopRoomOrder(ShopRoomOrder shopRoomOrder);

    /**
     * 修改酒店房间预订
     *
     * @param shopRoomOrder 酒店房间预订
     * @return 结果
     */
    public int updateShopRoomOrder(ShopRoomOrder shopRoomOrder);

    /**
     * 批量删除酒店房间预订
     *
     * @param ids 需要删除的酒店房间预订主键集合
     * @return 结果
     */
    public int deleteShopRoomOrderByIds(Long[] ids);

    /**
     * 删除酒店房间预订信息
     *
     * @param id 酒店房间预订主键
     * @return 结果
     */
    public int deleteShopRoomOrderById(Long id);

    public List<ShopRoomOrder> selectShopRoomOrder(ShopRoomOrder shopRoomOrder);
}
